@@ -14,17 +14,22 @@ def verify_response(success_code):
     :type success_code:     int
     :return:                Returns the results of the function this decorates.
     """
+
     def decorator(func):
         @wraps(func)
         def wrapper(self, *args, **kwargs):
             response = requests.get(self.request_url)
             if response.status_code != success_code:
-                raise Exception('The request to Tableau Server returned code \n'
-                                ' {} instead of {} in function {}'.format(response.status_code,
-                                                                          success_code,
-                                                                          func.__name__))
+                raise Exception(
+                    "The request to Tableau Server returned code \n"
+                    " {} instead of {} in function {}".format(
+                        response.status_code, success_code, func.__name__
+                    )
+                )
             return func(self, *args, **kwargs)
+
         return wrapper
+
     return decorator
 
 
@@ -37,12 +42,14 @@ def verify_signed_in(func):
     :type func:     function
     :return:        Returns the results of the function this decorates.
     """
+
     @wraps(func)
     def wrapper(self, *args, **kwargs):
         if self.auth_token:
             return func(self, *args, **kwargs)
         else:
-            raise Exception('The Tableau Server connection is not logged in.')
+            raise Exception("The Tableau Server connection is not logged in.")
+
     return wrapper
 
 
@@ -55,6 +62,7 @@ def verify_connection(func):
     :type func:     function
     :return:        Returns the results of the function this decorates.
     """
+
     @wraps(func)
     def wrapper(self, *args, **kwargs):
         print(args, kwargs)
@@ -62,7 +70,8 @@ def verify_connection(func):
             print(self.auth_token)
             return func(self, *args, **kwargs)
         else:
-            raise Exception('The Tableau Server connection is not logged in.')
+            raise Exception("The Tableau Server connection is not logged in.")
+
     return wrapper
 
 
@@ -75,26 +84,32 @@ def verify_config_variables(func):
     :type func:     function
     :return:        Returns the results of the function this decorates.
     """
+
     @wraps(func)
     def wrapper(self, *args, **kwargs):
-        required_config_variables = [
-            'server',
-            'api_version',
-            'site_name',
-            'site_url'
-        ]
+        required_config_variables = ["server", "api_version", "site_name", "site_url"]
         if (self._config and self._env) and type(self._config) == dict:
             config_variables = self._config[self._env].keys()
-            missing_required_variables = [variable for variable in required_config_variables
-                                          if variable not in config_variables]
+            missing_required_variables = [
+                variable
+                for variable in required_config_variables
+                if variable not in config_variables
+            ]
             if not any(missing_required_variables):
                 return func(self, *args, **kwargs)
             else:
-                raise ValueError("""
+                raise ValueError(
+                    """
                 The configuration variables provided are invalid.
                 Please provide the following missing configuration variables: {}
-                """.format(missing_required_variables))
-        raise Exception('Please provide a configuration dict to establish a connection.')
+                """.format(
+                        missing_required_variables
+                    )
+                )
+        raise Exception(
+            "Please provide a configuration dict to establish a connection."
+        )
+
     return wrapper
 
 
@@ -107,32 +122,42 @@ def verify_rest_api_version(func):
     :type func:     function
     :return:        Returns the results of the function this decorates.
     """
+
     @wraps(func)
     def wrapper(self, *args, **kwargs):
         if (self._config and self._env) and type(self._config) == dict:
             try:
                 server_info = self.server_info().json()
-                server_api_version = server_info['serverInfo']['restApiVersion']
-                if self._config[self._env]['api_version'] > server_api_version:
+                server_api_version = server_info["serverInfo"]["restApiVersion"]
+                if float(
+                    self._config[self._env]["api_version"].replace(".", "")
+                ) > float(server_api_version.replace(".", "")):
                     raise Exception("""Your API version is too damn high!""")
-                if self._config[self._env]['api_version'] < server_api_version:
-                    warnings.warn("""
+                if self._config[self._env]["api_version"] < server_api_version:
+                    warnings.warn(
+                        """
                     WARNING:
                     The Tableau Server REST API version you specified is lower than the version your server uses.
                     Your Tableau Server is on REST API version {0}.
                     The REST API version you specified is {1}.
                     For optimal results, please change the 'api_version' config variable to {0}.
-                    """.format(server_api_version, self._config[self._env]['api_version']))
+                    """.format(
+                            server_api_version, self._config[self._env]["api_version"]
+                        )
+                    )
             except (AttributeError, KeyError):
-                warnings.warn("""
+                warnings.warn(
+                    """
                 Warning: could not verify your Tableau Server's API version.
                 If using a legacy version of Tableau Server, be sure to reference the legacy Tableau Server
                 REST API documentation provided by Tableau.
                 Some current API methods may exist that are not available on your legacy Tableau Server.
-                """)
+                """
+                )
             return func(self, *args, **kwargs)
         else:
-            raise Exception('The Tableau Server connection is not logged in.')
+            raise Exception("The Tableau Server connection is not logged in.")
+
     return wrapper
 
 
@@ -143,14 +168,19 @@ def verify_api_method_exists(version_introduced):
     :param str version_introduced: the REST API version when the method was introduced
     :return: decorated function
     """
+
     def decorator(func):
         @wraps(func)
         def wrapper(self, *args, **kwargs):
-            conn_api_version = self._config[self._env]['api_version']
+            conn_api_version = self._config[self._env]["api_version"]
             if conn_api_version < version_introduced:
-                raise InvalidRestApiVersion(func,
-                                            api_version_used=conn_api_version,
-                                            api_version_required=version_introduced)
+                raise InvalidRestApiVersion(
+                    func,
+                    api_version_used=conn_api_version,
+                    api_version_required=version_introduced,
+                )
             return func(self, *args, **kwargs)
+
         return wrapper
+
     return decorator
